@@ -336,7 +336,20 @@ class BundlingOptions:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(BundlingOptions.__init__)
+            def stub(
+                *,
+                asset_hash: typing.Optional[builtins.str] = None,
+                asset_hash_type: typing.Optional[aws_cdk.core.AssetHashType] = None,
+                build_args: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                cgo_enabled: typing.Optional[builtins.bool] = None,
+                command_hooks: typing.Optional["ICommandHooks"] = None,
+                docker_image: typing.Optional[aws_cdk.core.DockerImage] = None,
+                environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                forced_docker_bundling: typing.Optional[builtins.bool] = None,
+                go_build_flags: typing.Optional[typing.Sequence[builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument asset_hash", value=asset_hash, expected_type=type_hints["asset_hash"])
             check_type(argname="argument asset_hash_type", value=asset_hash_type, expected_type=type_hints["asset_hash_type"])
             check_type(argname="argument build_args", value=build_args, expected_type=type_hints["build_args"])
@@ -627,7 +640,54 @@ class GoFunction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(GoFunction.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                entry: builtins.str,
+                bundling: typing.Optional[typing.Union[BundlingOptions, typing.Dict[str, typing.Any]]] = None,
+                module_dir: typing.Optional[builtins.str] = None,
+                runtime: typing.Optional[aws_cdk.aws_lambda.Runtime] = None,
+                allow_all_outbound: typing.Optional[builtins.bool] = None,
+                allow_public_subnet: typing.Optional[builtins.bool] = None,
+                architecture: typing.Optional[aws_cdk.aws_lambda.Architecture] = None,
+                architectures: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.Architecture]] = None,
+                code_signing_config: typing.Optional[aws_cdk.aws_lambda.ICodeSigningConfig] = None,
+                current_version_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.VersionOptions, typing.Dict[str, typing.Any]]] = None,
+                dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
+                dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
+                dead_letter_topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+                description: typing.Optional[builtins.str] = None,
+                environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                environment_encryption: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+                ephemeral_storage_size: typing.Optional[aws_cdk.core.Size] = None,
+                events: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.IEventSource]] = None,
+                filesystem: typing.Optional[aws_cdk.aws_lambda.FileSystem] = None,
+                function_name: typing.Optional[builtins.str] = None,
+                initial_policy: typing.Optional[typing.Sequence[aws_cdk.aws_iam.PolicyStatement]] = None,
+                insights_version: typing.Optional[aws_cdk.aws_lambda.LambdaInsightsVersion] = None,
+                layers: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.ILayerVersion]] = None,
+                log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
+                log_retention_retry_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.LogRetentionRetryOptions, typing.Dict[str, typing.Any]]] = None,
+                log_retention_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                memory_size: typing.Optional[jsii.Number] = None,
+                profiling: typing.Optional[builtins.bool] = None,
+                profiling_group: typing.Optional[aws_cdk.aws_codeguruprofiler.IProfilingGroup] = None,
+                reserved_concurrent_executions: typing.Optional[jsii.Number] = None,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
+                security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
+                timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                tracing: typing.Optional[aws_cdk.aws_lambda.Tracing] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+                max_event_age: typing.Optional[aws_cdk.core.Duration] = None,
+                on_failure: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
+                on_success: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
+                retry_attempts: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GoFunctionProps(
@@ -835,7 +895,52 @@ class GoFunctionProps(aws_cdk.aws_lambda.FunctionOptions):
         if isinstance(bundling, dict):
             bundling = BundlingOptions(**bundling)
         if __debug__:
-            type_hints = typing.get_type_hints(GoFunctionProps.__init__)
+            def stub(
+                *,
+                max_event_age: typing.Optional[aws_cdk.core.Duration] = None,
+                on_failure: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
+                on_success: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
+                retry_attempts: typing.Optional[jsii.Number] = None,
+                allow_all_outbound: typing.Optional[builtins.bool] = None,
+                allow_public_subnet: typing.Optional[builtins.bool] = None,
+                architecture: typing.Optional[aws_cdk.aws_lambda.Architecture] = None,
+                architectures: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.Architecture]] = None,
+                code_signing_config: typing.Optional[aws_cdk.aws_lambda.ICodeSigningConfig] = None,
+                current_version_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.VersionOptions, typing.Dict[str, typing.Any]]] = None,
+                dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
+                dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
+                dead_letter_topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+                description: typing.Optional[builtins.str] = None,
+                environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                environment_encryption: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+                ephemeral_storage_size: typing.Optional[aws_cdk.core.Size] = None,
+                events: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.IEventSource]] = None,
+                filesystem: typing.Optional[aws_cdk.aws_lambda.FileSystem] = None,
+                function_name: typing.Optional[builtins.str] = None,
+                initial_policy: typing.Optional[typing.Sequence[aws_cdk.aws_iam.PolicyStatement]] = None,
+                insights_version: typing.Optional[aws_cdk.aws_lambda.LambdaInsightsVersion] = None,
+                layers: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.ILayerVersion]] = None,
+                log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
+                log_retention_retry_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.LogRetentionRetryOptions, typing.Dict[str, typing.Any]]] = None,
+                log_retention_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                memory_size: typing.Optional[jsii.Number] = None,
+                profiling: typing.Optional[builtins.bool] = None,
+                profiling_group: typing.Optional[aws_cdk.aws_codeguruprofiler.IProfilingGroup] = None,
+                reserved_concurrent_executions: typing.Optional[jsii.Number] = None,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
+                security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
+                timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                tracing: typing.Optional[aws_cdk.aws_lambda.Tracing] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+                entry: builtins.str,
+                bundling: typing.Optional[typing.Union[BundlingOptions, typing.Dict[str, typing.Any]]] = None,
+                module_dir: typing.Optional[builtins.str] = None,
+                runtime: typing.Optional[aws_cdk.aws_lambda.Runtime] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument max_event_age", value=max_event_age, expected_type=type_hints["max_event_age"])
             check_type(argname="argument on_failure", value=on_failure, expected_type=type_hints["on_failure"])
             check_type(argname="argument on_success", value=on_success, expected_type=type_hints["on_success"])
@@ -1591,7 +1696,9 @@ class _ICommandHooksProxy:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ICommandHooks.after_bundling)
+            def stub(input_dir: builtins.str, output_dir: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument input_dir", value=input_dir, expected_type=type_hints["input_dir"])
             check_type(argname="argument output_dir", value=output_dir, expected_type=type_hints["output_dir"])
         return typing.cast(typing.List[builtins.str], jsii.invoke(self, "afterBundling", [input_dir, output_dir]))
@@ -1612,7 +1719,9 @@ class _ICommandHooksProxy:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ICommandHooks.before_bundling)
+            def stub(input_dir: builtins.str, output_dir: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument input_dir", value=input_dir, expected_type=type_hints["input_dir"])
             check_type(argname="argument output_dir", value=output_dir, expected_type=type_hints["output_dir"])
         return typing.cast(typing.List[builtins.str], jsii.invoke(self, "beforeBundling", [input_dir, output_dir]))
